@@ -3,8 +3,11 @@
 mod callback_data;
 mod response_type;
 
-pub use self::{callback_data::CallbackData, response_type::ResponseType};
+pub use self::{
+    callback_data::Autocomplete, callback_data::CallbackData, response_type::ResponseType,
+};
 
+use callback_data::CallbackDataEnvelope;
 use serde::{
     de::{Deserializer, Error as DeError, IgnoredAny, MapAccess, Visitor},
     ser::{SerializeStruct, Serializer},
@@ -31,6 +34,8 @@ pub enum InteractionResponse {
     DeferredUpdateMessage,
     /// Edit the message a component is attached to.
     UpdateMessage(CallbackData),
+    /// Autocomplete results.
+    Autocomplete(Autocomplete),
 }
 
 impl InteractionResponse {
@@ -58,6 +63,7 @@ impl InteractionResponse {
     /// [`Pong`]: Self::Pong
     pub const fn kind(&self) -> ResponseType {
         match self {
+            Self::Autocomplete(_) => ResponseType::ApplicationCommandAutocompleteResult,
             Self::Pong => ResponseType::Pong,
             Self::ChannelMessageWithSource(_) => ResponseType::ChannelMessageWithSource,
             Self::DeferredChannelMessageWithSource(_) => {
@@ -92,7 +98,7 @@ impl<'de> Visitor<'de> for ResponseVisitor {
     }
 
     fn visit_map<V: MapAccess<'de>>(self, mut map: V) -> Result<Self::Value, V::Error> {
-        let mut data: Option<CallbackData> = None;
+        let mut data: Option<CallbackDataEnvelope> = None;
         let mut kind: Option<ResponseType> = None;
 
         let span = tracing::trace_span!("deserializing interaction response");
@@ -138,24 +144,30 @@ impl<'de> Visitor<'de> for ResponseVisitor {
 
         let kind = kind.ok_or_else(|| DeError::missing_field("type"))?;
 
-        Ok(match kind {
-            ResponseType::Pong => Self::Value::Pong,
-            ResponseType::ChannelMessageWithSource => {
-                let data = data.ok_or_else(|| DeError::missing_field("data"))?;
-
-                Self::Value::ChannelMessageWithSource(data)
-            }
-            ResponseType::DeferredChannelMessageWithSource => {
-                let data = data.ok_or_else(|| DeError::missing_field("data"))?;
-
-                Self::Value::DeferredChannelMessageWithSource(data)
-            }
-            ResponseType::DeferredUpdateMessage => Self::Value::DeferredUpdateMessage,
-            ResponseType::UpdateMessage => {
-                let data = data.ok_or_else(|| DeError::missing_field("data"))?;
-
+        Ok(match (kind, data) {
+            (ResponseType::Pong, _) => Self::Value::Pong,
+            (
+                ResponseType::ChannelMessageWithSource,
+                Some(CallbackDataEnvelope::Messages(data)),
+            ) => Self::Value::ChannelMessageWithSource(data),
+            (
+                ResponseType::DeferredChannelMessageWithSource,
+                Some(CallbackDataEnvelope::Messages(data)),
+            ) => Self::Value::DeferredChannelMessageWithSource(data),
+            (ResponseType::DeferredUpdateMessage, _) => Self::Value::DeferredUpdateMessage,
+            (ResponseType::UpdateMessage, Some(CallbackDataEnvelope::Messages(data))) => {
                 Self::Value::UpdateMessage(data)
             }
+            (
+                ResponseType::ApplicationCommandAutocompleteResult,
+                Some(CallbackDataEnvelope::Autocomplete(data)),
+            ) => Self::Value::Autocomplete(data),
+            (t, d) => {
+                return Err(DeError::custom(format!(
+                    "unknown type/data combination: type={:?} data={:?}",
+                    t, d
+                )))
+            }
         })
     }
 }
@@ -163,6 +175,14 @@ impl<'de> Visitor<'de> for ResponseVisitor {
 impl Serialize for InteractionResponse {
     fn serialize<S: Serializer>(&self, serializer: S) -> Result<S::Ok, S::Error> {
         match self {
+            Self::Autocomplete(data) => {
+                let mut state = serializer.serialize_struct("InteractionResponse", 2)?;
+
+                state.serialize_field("type", &self.kind())?;
+                state.serialize_field("data", &data)?;
+
+                state.end()
+            }
             Self::Pong | Self::DeferredUpdateMessage => {
                 let mut state = serializer.serialize_struct("InteractionResponse", 1)?;
 
