@@ -6,9 +6,14 @@ use serde::{
 
 bitflags! {
     pub struct SystemChannelFlags: u64 {
+        /// Suppress member join notifications.
         const SUPPRESS_JOIN_NOTIFICATIONS = 1;
+        /// Suppress server boost notifications.
         const SUPPRESS_PREMIUM_SUBSCRIPTIONS = 1 << 1;
+        /// Suppress server setup tips.
         const SUPPRESS_GUILD_REMINDER_NOTIFICATIONS = 1 << 2;
+        /// Hide member join sticker reply buttons.
+        const SUPPRESS_JOIN_NOTIFICATION_REPLIES = 1 << 3;
     }
 }
 
