@@ -85,20 +85,20 @@ mod tests {
             bot_require_code_grant: false,
             cover_image: Some("cover image hash".to_owned()),
             description: "a pretty cool application".to_owned(),
-            guild_id: Some(GuildId(1)),
+            guild_id: Some(GuildId::new(1).expect("non zero")),
             flags: Some(ApplicationFlags::EMBEDDED),
             icon: Some("icon hash".to_owned()),
-            id: ApplicationId(2),
+            id: ApplicationId::new(2).expect("non zero"),
             name: "cool application".to_owned(),
             owner: User {
                 accent_color: None,
                 avatar: None,
                 banner: None,
                 bot: false,
-                discriminator: "0001".to_owned(),
+                discriminator: 1,
                 email: None,
                 flags: None,
-                id: UserId(3),
+                id: UserId::new(3).expect("non zero"),
                 locale: None,
                 mfa_enabled: None,
                 name: "app dev".to_owned(),
@@ -114,10 +114,10 @@ mod tests {
             summary: "a summary".to_owned(),
             team: Some(Team {
                 icon: None,
-                id: TeamId(5),
+                id: TeamId::new(5).expect("non zero"),
                 members: Vec::new(),
                 name: "team name".into(),
-                owner_user_id: UserId(6),
+                owner_user_id: UserId::new(6).expect("non zero"),
             }),
             terms_of_service_url: Some("https://termsofservice".into()),
             verify_key: "key".to_owned(),
